@@ -5,10 +5,10 @@ from apispec import APISpec
 from apispec.ext.marshmallow import MarshmallowPlugin
 from starlette.applications import Starlette
 from starlette.requests import Request
-from starlette.responses import JSONResponse
+from starlette.responses import JSONResponse, HTMLResponse
 
 from .route import setup_routes
-from .utils import resolve_schema_name
+from .utils import resolve_schema_name, apispec_json_to_html
 
 logger = logging.getLogger(__name__)
 
@@ -21,6 +21,7 @@ def setup_spec(app: Starlette, title: str,
                schemes=None,
                base_path='/',
                route: str = '/apidocs.json',
+               route_html: str = '/apidocs',
                add_head_methods: bool = False,
                options: Optional[Mapping] = None,
                **kwargs):
@@ -39,15 +40,22 @@ def setup_spec(app: Starlette, title: str,
 
     @app.route(route, include_in_schema=False)
     def generate_api_docs(_: Request):
+        s = generate_spec(app, get_open_api_version(openapi_version), add_head_methods)
+        return JSONResponse(s)
+
+    @app.route(route_html, include_in_schema=False)
+    def generate_html_api_docs(_: Request):
+        s = generate_spec(app, get_open_api_version(openapi_version), add_head_methods)
+        return HTMLResponse(apispec_json_to_html(s))
+
+    def generate_spec(app: Starlette, open_api_version: int, add_head_methods: bool):
         nonlocal api_spec
         nonlocal spec
         if api_spec is None:
             logger.info('initialize open api schema')
-            setup_routes(app.routes, spec, version=get_open_api_version(openapi_version)
-                         , add_head_methods=add_head_methods)
+            setup_routes(app.routes, spec, version=open_api_version, add_head_methods=add_head_methods)
             api_spec = spec.to_dict()
-
-        return JSONResponse(api_spec)
+        return api_spec
 
 
 def get_open_api_version(version: str) -> int:
